4.51. umbra.ui.widgets.application_QToolBar — Umbra 1.0.9 documentation

# 4.51. umbra.ui.widgets.application_QToolBar

application_QToolBar.py.py

Platform:
  Windows, Linux, Mac Os X.
Description:
  Defines the `Application_QToolBar` class.

Others:

## 4.51.1. Module Attributes

`umbra.ui.widgets.application_QToolBar.` `LOGGER`

## 4.51.2. Classes

class `umbra.ui.widgets.application_QToolBar.` `Application_QToolBar`(parent=None)

  Bases: `PyQt4.QtGui.QToolBar`

  Defines a QToolBar subclass providing the Application toolbar.

  Initializes the class.

  Parameters: | parent (QObject) – Widget parent.

  `container`

    Property for self.__container attribute.

    Returns: | self.__container.
    Return type: | QObject

  `settings`

    Property for self.__settings attribute.

    Returns: | self.__settings.
    Return type: | Preferences

  `layoutsActiveLabelsCollection`

    Property for self.__layoutsActiveLabelsCollection attribute.

    Returns: | self.__layoutsActiveLabelsCollection.
    Return type: | Active_QLabelsCollection

  `customLayoutsMenu`

    Property for self.__customLayoutsMenu attribute.

    Returns: | self.__customLayoutsMenu.
    Return type: | QMenu

  `miscellaneousMenu`

    Property for self.__miscellaneousMenu attribute.

    Returns: | self.__miscellaneousMenu.
    Return type: | QMenu

  `setLayoutDefaultGeometry`()

    Sets the toolBar layout default geometry.

    Returns: | Method success.
    Return type: | bool

  `setToolBarChildrenWidgets`()

    Sets the toolBar children widgets.

    Returns: | Method success.
    Return type: | bool

  `getApplicationLogoLabel`()

    Provides the default Application_Logo_label widget.

    Returns: | Application logo label.
    Return type: | QLabel

  `getLayoutActiveLabel`(resources, name, title, identity, shortcut)

    Returns a layout Active_QLabel widget.

    Parameters: | resources (tuple) – Icons resources ( Default / Hover / Active ). name (unicode) – Ui object name. title (unicode) – Layout registration title. identity (unicode) – Layout code name. shortcut – Layout associated shortcut. ( QtCore.Key )
    Returns: | Layout active label.
    Return type: | Active_QLabel

  `getLayoutsActiveLabels`()

    Returns the layouts Active_QLabel widgets.

    Returns: | Layouts active labels.
    Return type: | list

  `getCustomLayoutsActiveLabel`()

    Provides the default Custom_Layouts_activeLabel widget.

    Returns: | Layout active label.
    Return type: | Active_QLabel

  `getMiscellaneousActiveLabel`()

    Provides the default Miscellaneous_activeLabel widget.

    Returns: | Miscellaneous active label.
    Return type: | Active_QLabel

  `getSpacerLabel`()

    Provides the default Spacer_label widget.

    Returns: | Logo spacer label.
    Return type: | QLabel

  `getClosureSpacerLabel`()

    Provides the default Closure_Spacer_label widget.

    Returns: | Closure spacer label.
    Return type: | QLabel